Skip to contents

A dataset containing interval-censored observations and a treatment indicator (radiation vs. radiation plus chemotherapy). The variables are as follows:

Usage

data(bcos)

Format

A data frame with 94 rows and 3 variables:

left

Left endpoints of the censoring intervals (numeric).

right

Right endpoints of the censoring intervals (numeric).

treatment

A factor with levels "Rad" (radiation only) or "RadChem" (radiation + chemotherapy).

Details

These data are often used to illustrate methods for interval-censored survival analysis. Observations with Inf in the right endpoint represent right-censored data.

Examples

data(bcos)
head(bcos)
#>   left right treatment
#> 1   45   Inf       Rad
#> 2    6    10       Rad
#> 3    0     7       Rad
#> 4   46   Inf       Rad
#> 5   46   Inf       Rad
#> 6    7    16       Rad