Computes a piecewise-linear convex minorant of two numeric vectors G
and Q by iteratively identifying minimum slopes and assigning them to
the output vector y. This method is sometimes used in isotonic or
shape-constrained regression contexts.
Computes a piecewise-linear convex minorant of two numeric vectors G
and Q by iteratively identifying minimum slopes and assigning them to
the output vector y. This method is sometimes used in isotonic or
shape-constrained regression contexts.